@@ -1,23 +1,41 @@
 import click
 import sys
 
-from . import version
+from pathlib import Path
+__env_path__ = Path.home() / ".tradologics"
+
+try:
+    from .envdev import ENVIRONMENT
+except ImportError:
+    from .env import ENVIRONMENT
+
+if ENVIRONMENT == "dev":
+    __env_path__ = Path.home() / ".tradologics-dev"
 
 # internals
+from . import version
 from . import config
-from . import brokers
 from . import accounts
-from . import assets
+from . import pricing
+from . import universe
 from . import strategies
 from . import tradehooks
 from . import monitors
 from . import orders
 from . import trading
 from . import tokens
+from . import upgrade
+from . import me
+from . import remote
 
 
 if "--version" in sys.argv or "-V" in sys.argv:
-    click.echo("\ntctl {version}".format(version=version.version))
+    data, errors = remote.api.get("/version", halt_on_error=False)
+    if data:
+        click.echo(f"\nTctl {version.version} / System {data['version']}")
+    else:
+        click.echo(f"\nTctl {version.version}")
+
     click.echo("Copyrights (c) Tradologics, Inc.")
     click.echo("https://tradologics.com")
     sys.exit()
@@ -25,15 +43,17 @@ if "--version" in sys.argv or "-V" in sys.argv:
 
 cli = click.CommandCollection(sources=[
     config.cli,
-    brokers.cli,
     accounts.cli,
-    assets.cli,
+    pricing.cli,
+    universe.cli,
     strategies.cli,
     tradehooks.cli,
     monitors.cli,
     orders.cli,
     trading.cli,
-    tokens.cli
+    tokens.cli,
+    upgrade.cli,
+    me.cli,
 ])
 
 
