@@ -11,9 +11,25 @@ import pandas as pd
 pd.options.display.float_format = '{:,}'.format
 
 
+def _format_order(order):
+    order["description"] = order['asset']['name']
+    order["currency"] = order['asset']['currency']
+    asset = f"{order['asset']['ticker']}"
+    if "region" in order['asset']:
+        asset += f":{order['asset']['region']}"
+    order["asset"] = asset
+
+    order["filled_qty"] = "{:,.0f}".format(Decimal(order["filled_qty"]))
+    order["qty"] = "{:,.0f}".format(Decimal(order["qty"]))
+    for col in ['avg_fill_price', 'limit_price', 'stop_price']:
+        order[col] = utils.to_decimal(order[col])
+
+    return order
+
+
 def orders_list(options):
     account = options.first("account")
-    # accounts_data = remote.api.get("/accounts")
+    # accounts_data, errors = remote.api.get("/accounts")
     # accounts = {k: v["name"] for k, v in accounts_data.items()}
 
     # if account not in accounts:
@@ -34,15 +50,15 @@ def orders_list(options):
         payload["statuses"] = options.get("status")
 
     if payload:
-        data = remote.api.get(endpoint, json=payload)
+        data, errors = remote.api.get(endpoint, json=payload)
     else:
-        data = remote.api.get(endpoint)
+        data, errors = remote.api.get(endpoint)
 
     if options.get("raw"):
         if not data:
             click.echo("\n[]")
         else:
-            click.echo(utils.to_json(data))
+            click.echo(utils.to_json(data, errors))
         return
 
     if not data:
@@ -60,21 +76,44 @@ def orders_list(options):
             })
     else:
         # display  order list
-        if not data.get(account):
+        if not data:
             click.echo("\nNo orders found for account {}".format(account))
             return
 
-        for item in data.get(account):
-            table_data.append({
-                "id": item["order_id"],
-                "asset": item["ticker"],
-                "side": item["side"],
-                "qty": "{:,.0f}".format(Decimal(item["qty"])),
-                "filled_qty": "{:,.0f}".format(Decimal(item["filled_qty"])),
-                "avg_fill_price": item["avg_fill_price"],
-                "status": item["status"]
-            })
-    click.echo(utils.to_table(table_data))
+        rows = []
+        for row in data:
+            for col in ['qty', 'filled_qty', 'avg_fill_price']:
+                row[col] = utils.to_decimal(row[col])
+
+            row["currency"] = row['asset']['currency']
+            row["asset"] = f"{row['asset']['ticker']}:{row['asset']['region']}"
+
+            rows.append(row)
+
+        cols = [
+            'asset', 'qty', 'filled_qty',
+            'side', 'type', 'tif',
+            'limit_price', 'stop_price'
+            'avg_fill_price', 'status',
+            'created_at', 'updated_at',
+            'comment', 'strategy_id',
+            'account_id', 'currency']
+
+        if options.first('ids', False):
+            cols = ['order_id'] + cols
+
+        df = pd.DataFrame(rows)
+        df = df[[col for col in cols if col in df.columns]]
+        # print(df.columns)
+
+        if len(df) > 20:
+            click.echo_via_pager(utils.to_table(df))
+        else:
+            click.echo(utils.to_table(df))
+
+    if errors:
+        click.echo("\nErrors:")
+        click.echo(utils.to_table(errors))
 
 
 def order_create(options):
@@ -122,7 +161,7 @@ def order_create(options):
         payload["stop_price"] = price
 
     strategies = {}
-    supported_strategies = remote.api.get("/strategies")
+    supported_strategies, errors = remote.api.get("/strategies")
     for strategy in supported_strategies:
         strategies[strategy['name']] = strategy["strategy_id"]
 
@@ -134,7 +173,7 @@ def order_create(options):
         click.echo("You *must* be associate this order with a strategy.")
 
     accounts = {}
-    supported_accounts = remote.api.get("/accounts")
+    supported_accounts, errors = remote.api.get("/accounts")
     for key, account in supported_accounts.items():
         accounts[account['name']] = account["account_id"]
     selected_account = accounts[inputs.option_selector(
@@ -145,61 +184,67 @@ def order_create(options):
 
     payload["comment"] = inputs.text("Comment (optional)")
 
-    payload["submit"] = not inputs.confirm(
+    payload["submit"] = inputs.confirm(
         "Submit order? (no will create an order that you can submit later)", default=True)
 
-    data = remote.api.post(f"/orders", json=payload)
+    print(utils.to_json(payload))
+    # return
+    data, errors = remote.api.post(f"/orders", json=payload)
 
     if options.get("raw"):
-        click.echo(utils.to_json(data))
+        click.echo(utils.to_json(data, errors))
         return
 
     and_submitted = " and submitted" if payload["submit"] else ""
     utils.success_response(
         f"The order was created{and_submitted} successfully.")
 
-    click.echo(f"Order Id: {data['id']}")
+    click.echo(f"Order Id: {data['order_id']}")
 
-    df = pd.DataFrame([data])
+    df = pd.DataFrame([_format_order(data)])
     df.columns = [col.replace("_", " ").title() for col in df.columns]
     click.echo(utils.to_table(
             df.T, missingval="-", showindex=True, showheaders=False))
 
 
 def order_info(options):
-    data = remote.api.get("/order/{order}".format(
+    data, errors = remote.api.get("/order/{order}".format(
         order=options.first("order")))
 
     if options.get("raw"):
         if not data:
             click.echo("\n[]")
         else:
-            click.echo(utils.to_json(data))
+            click.echo(utils.to_json(data, errors))
         return
 
     if not data:
         click.echo("\nNo strategies found.")
         return
 
-    df = pd.DataFrame([data])
+    df = pd.DataFrame([_format_order(data)])
     df.columns = [col.replace("_", " ").title() for col in df.columns]
     click.echo(utils.to_table(df.T, showindex=True, showheaders=False))
 
+    if errors:
+        click.echo("\nErrors:")
+        click.echo(utils.to_table(errors))
+
 
 def order_delete(options):
-    monitor = options.first("order")
-    remote.api.delete("/orders/{order}".format(
+    order = options.first("order")
+    remote.api.delete("/order/{order}".format(
         order=options.first("order")))
 
     utils.success_response(
-        f"The order `{monitor}` was cancelled successfully.")
+        f"The order `{order}` was cancelled successfully.")
 
 
 def order_update(options):
     click.echo("")
 
     order_id = options.first("order")
-    order = remote.api.get(f"/order/{order_id}")
+    order, errors = remote.api.get(f"/order/{order_id}")
 
     if order.get("status") not in ["submitted", "accepted"]:
         click.echo(click.style("\nFAILED", fg="red"))
@@ -246,7 +291,7 @@ def order_update(options):
         payload["stop_price"] = price
 
     strategies = {}
-    supported_strategies = remote.api.get("/strategies")
+    supported_strategies, errors = remote.api.get("/strategies")
     for strategy in supported_strategies:
         strategies[strategy['name']] = strategy["strategy_id"]
 
@@ -264,10 +309,10 @@ def order_update(options):
     payload["submit"] = not inputs.confirm(
         "Submit order? (no will create an order that you can submit later)", default=True)
 
-    data = remote.api.patch(f"/orders/{order_id}", json=payload)
+    data, errors = remote.api.patch(f"/orders/{order_id}", json=payload)
 
     if options.get("raw"):
-        click.echo(utils.to_json(data))
+        click.echo(utils.to_json(data, errors))
         return
 
     and_submitted = " and submitted" if payload["submit"] else ""
@@ -282,3 +327,11 @@ def order_update(options):
             df.T, missingval="-", showindex=True, showheaders=False))
 
 
+def order_submit(options):
+    order = options.first("order")
+    remote.api.post("/order/{order}".format(
+        order=options.first("order")))
+
+    utils.success_response(
+        f"The order `{order}` was submitted successfully.")
+
