@@ -4,16 +4,19 @@ import requests
 from requests.exceptions import ConnectionError
 import click
 
-from . import utils
+from . import utils, upgrade
 from . import credentials
-from .env import BASE_URL
+try:
+    from .envdev import BASE_URL
+except ImportError:
+    from .env import BASE_URL
 
 
-def _parse_response(response_obj):
+def _parse_response(response_obj, halt_on_error=True):
     # "no content" response
     if not response_obj.headers.get('Content-Type') and \
             response_obj.status_code in [201, 202, 204]:
-        return None
+        return None, None
 
     data = {}
     try:
@@ -24,7 +27,7 @@ def _parse_response(response_obj):
 
     data["status_code"] = response_obj.status_code
 
-    if int(data["status_code"] / 100) != 2:
+    if halt_on_error and int(data["status_code"] / 100) != 2:
         error = data.get("errors", [{
             "id": "invalid_request",
             "message": "Cannot process request"
@@ -37,36 +40,41 @@ def _parse_response(response_obj):
         click.echo(utils.to_json(error))
         sys.exit()
 
-    return data.get("data", {})
+    return data.get("data", {}), data.get("errors", {})
 
 
 def bearer_token():
+    upgrade.check_for_new_version()
+
     token = os.getenv("TOKEN")
     if not token:
         credentials.config()
-    token = credentials.decrypt(token)
+    token = utils.decrypt(token)
     return {"Authorization": "Bearer {token}".format(token=token)}
 
 
 def full_url(endpoint):
-    return "{url}{endpoint}".format(url=BASE_URL, endpoint=endpoint)
+    if "http://" in endpoint or "https://" in endpoint:
+        return endpoint
+    return "{url}/{endpoint}".format(
+        url=BASE_URL.strip('/'), endpoint=endpoint.strip('/'))
 
 
 class api:
 
     @staticmethod
-    def get(endpoint, **kwargs):
+    def get(endpoint, halt_on_error=True, **kwargs):
         if "headers" not in kwargs:
             kwargs["headers"] = bearer_token()
         try:
             r = requests.get(full_url(endpoint), **kwargs)
-            return _parse_response(r)
+            return _parse_response(r, halt_on_error)
         except ConnectionError:
             click.echo("ERROR: Cannot establish connection to Tradologics")
             sys.exit()
 
     @staticmethod
-    def post(endpoint, **kwargs):
+    def post(endpoint, halt_on_error=True, **kwargs):
         try:
             if "headers" not in kwargs:
                 kwargs["headers"] = bearer_token()
@@ -74,13 +82,13 @@ class api:
                 kwargs["timeout"] = 2
 
             r = requests.post(full_url(endpoint), **kwargs)
-            return _parse_response(r)
+            return _parse_response(r, halt_on_error)
         except ConnectionError:
             click.echo("ERROR: Cannot establish connection to Tradologics")
             sys.exit()
 
     @staticmethod
-    def patch(endpoint, **kwargs):
+    def patch(endpoint, halt_on_error=True, **kwargs):
         try:
             if "headers" not in kwargs:
                 kwargs["headers"] = bearer_token()
@@ -88,13 +96,13 @@ class api:
                 kwargs["timeout"] = 2
 
             r = requests.patch(full_url(endpoint), **kwargs)
-            return _parse_response(r)
+            return _parse_response(r, halt_on_error)
         except ConnectionError:
             click.echo("ERROR: Cannot establish connection to Tradologics")
             sys.exit()
 
     @staticmethod
-    def put(endpoint, **kwargs):
+    def put(endpoint, halt_on_error=True, **kwargs):
         try:
             if "headers" not in kwargs:
                 kwargs["headers"] = bearer_token()
@@ -102,27 +110,26 @@ class api:
                 kwargs["timeout"] = 2
 
             r = requests.put(full_url(endpoint), **kwargs)
-            return _parse_response(r)
+            return _parse_response(r, halt_on_error)
         except ConnectionError:
             click.echo("ERROR: Cannot establish connection to Tradologics")
             sys.exit()
 
     @staticmethod
-    def delete(endpoint, **kwargs):
+    def delete(endpoint, halt_on_error=True, **kwargs):
         try:
             if "headers" not in kwargs:
                 kwargs["headers"] = bearer_token()
             if "timeout" not in kwargs:
                 kwargs["timeout"] = 2
-
             r = requests.delete(full_url(endpoint), **kwargs)
-            return _parse_response(r)
+            return _parse_response(r, halt_on_error)
         except ConnectionError:
             click.echo("ERROR: Cannot establish connection to Tradologics")
             sys.exit()
 
     @staticmethod
-    def options(endpoint, **kwargs):
+    def options(endpoint, halt_on_error=True, **kwargs):
         try:
             if "headers" not in kwargs:
                 kwargs["headers"] = bearer_token()
@@ -130,13 +137,13 @@ class api:
                 kwargs["timeout"] = 2
 
             r = requests.options(full_url(endpoint), **kwargs)
-            return _parse_response(r)
+            return _parse_response(r, halt_on_error)
         except ConnectionError:
             click.echo("ERROR: Cannot establish connection to Tradologics")
             sys.exit()
 
     @staticmethod
-    def head(endpoint, **kwargs):
+    def head(endpoint, halt_on_error=True, **kwargs):
         try:
             if "headers" not in kwargs:
                 kwargs["headers"] = bearer_token()
@@ -144,7 +151,7 @@ class api:
                 kwargs["timeout"] = 2
 
             r = requests.head(full_url(endpoint), **kwargs)
-            return _parse_response(r)
+            return _parse_response(r, halt_on_error)
         except ConnectionError:
             click.echo("ERROR: Cannot establish connection to Tradologics")
             sys.exit()
